========
|pic1|
========

.. |pic1| image:: pynapple_logo.png
   :width: 80%


.. image:: https://img.shields.io/pypi/v/pynapple.svg
        :target: https://pypi.python.org/pypi/pynapple

.. image:: https://img.shields.io/travis/gviejo/pynapple.svg
        :target: https://travis-ci.com/gviejo/pynapple

.. image:: https://readthedocs.org/projects/pynapple/badge/?version=latest
        :target: https://pynapple.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




PYthon Neural Analysis Package Pour Laboratoires d’Excellence

pynapple is a Python library for analysing neurophysiological data. It allows to handle time series and epochs but also to use generic functions for neuroscience such as tuning curves and cross-correlogram of spikes. It is heavily based on neuroseries.



* Free software: GNU General Public License v3
* Documentation: https://pynapple.readthedocs.io.

----------------------------

Installing pynapple
===================


+-------------------------------------------+---------------------------------------------------+
|      **With pip** (recommended)           |         **With conda**                            |
+-------------------------------------------+---------------------------------------------------+
|                                           |                                                   |
| .. code::                                 | .. code::                                         |
|                                           |                                                   |
|   pip install pynapple                    |   conda install -c conda-forge pynapple           |
|                                           |                                                   |
|                                           |                                                   |
+-------------------------------------------+---------------------------------------------------+
|                               **Development (from git)**                                      |
+-------------------------------------------+---------------------------------------------------+
|                                                                                               |
|          .. code::                                                                            |
|                                                                                               |
|             # clone the repository                                                            |
|             git clone https://github.com/PeyracheLab/pynapple.git                             |
|             cd pynapple                                                                       |
|             # Install in editable mode with `-e` or, equivalently, `--editable`               |
|             pip install -e .                                                                  |
|                                                                                               |
+-----------------------------------------------------------------------------------------------+  
 

------------------


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
